@@ -1,7 +1,7 @@
 #ifndef LIBXL_C_H
 #define LIBXL_C_H
 
-#define LIBXL_VERSION 0x03080100
+#define LIBXL_VERSION 0x03080400
 
 #ifdef _UNICODE
 
@@ -20,12 +20,15 @@
     #define xlBookSaveUsingTempFile xlBookSaveUsingTempFileW
     #define xlBookLoadPartially xlBookLoadPartiallyW
     #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileW
+    #define xlBookLoadWithoutEmptyCells xlBookLoadWithoutEmptyCellsW
+    #define xlBookLoadInfo xlBookLoadInfoW
     #define xlBookLoadRaw xlBookLoadRawW
     #define xlBookLoadRawPartially xlBookLoadRawPartiallyW
     #define xlBookSaveRaw xlBookSaveRawW
     #define xlBookAddSheet xlBookAddSheetW
     #define xlBookInsertSheet xlBookInsertSheetW
     #define xlBookGetSheet xlBookGetSheetW
+    #define xlBookGetSheetName xlBookGetSheetNameW
     #define xlBookSheetType xlBookSheetTypeW
     #define xlBookMoveSheet xlBookMoveSheetW
     #define xlBookDelSheet xlBookDelSheetW
@@ -316,12 +319,15 @@
     #define xlBookSaveUsingTempFile xlBookSaveUsingTempFileA
     #define xlBookLoadPartially xlBookLoadPartiallyA
     #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileA
+    #define xlBookLoadWithoutEmptyCells xlBookLoadWithoutEmptyCellsA
+    #define xlBookLoadInfo xlBookLoadInfoA
     #define xlBookLoadRaw xlBookLoadRawA
     #define xlBookLoadRawPartially xlBookLoadRawPartiallyA
     #define xlBookSaveRaw xlBookSaveRawA
     #define xlBookAddSheet xlBookAddSheetA
     #define xlBookInsertSheet xlBookInsertSheetA
     #define xlBookGetSheet xlBookGetSheetA
+    #define xlBookGetSheetName xlBookGetSheetNameA
     #define xlBookSheetType xlBookSheetTypeA
     #define xlBookMoveSheet xlBookMoveSheetA
     #define xlBookDelSheet xlBookDelSheetA
